@@ -254,16 +254,14 @@ function(x, y=NULL, scale=1.5, order=3, ctrl=car_control())
                          pre1=double(n.ahead),
                          prv1=double(n.ahead),
                          tim1=double(ntim),
+                         pre2=double(5000),
+                         prv2=double(5000),
                          package="cts")
         pre <- Zfor$pre1
         prv <- Zfor$prv1
         tim <- Zfor$tim1
-      cat("\n")
-      print(pre)
-      cat("\n")
-      print(prv)
-      cat("\n")
-      print(tim)
+        pre2 <- Zfor$pre2[Zfor$prv2 > 0]
+        prv2 <- Zfor$prv2[Zfor$prv2 > 0]
       }
     else
       {
@@ -288,7 +286,7 @@ function(x, y=NULL, scale=1.5, order=3, ctrl=car_control())
                    filser=filser,filvar=filvar,
                    sser=sser,svar=svar,
                    stdres=sres, pretime = tim[(ntim1+1):ntim2],
-                   predict=pre,predict.var=prv*Z$sigsq1, fty=fty, tnit=zpar$tnit, ss=zpar$ss, bit=zpar$bit, aic=aic, bic=bic),
+                   predict=pre,predict.var=prv*Z$sigsq1, pre2=pre2, prv2=prv2*Z$sigsq1, fty=fty, tnit=zpar$tnit, ss=zpar$ss, bit=zpar$bit, aic=aic, bic=bic),
               class="car")
   }
 
