@@ -1,5 +1,5 @@
-      subroutine setcom(PFI1,ARP1,NP1,VRI1,CCV1,LEN1,SCALE1,VR1,SIGSQ1,
-     *ESSP1,ECOV1,B1,DELB1,ROOTR1,ROOTI1)
+      subroutine setcom(PFI1,ARP1,NP1,VRI1,CCV1,LEN1,SCALE1,VR1,
+     * SIGSQ1,ESSP1,ECOV1,B1,DELB1,ROOTR1,ROOTI1)
       IMPLICIT NONE 
       INTEGER I,J
 c      INCLUDE 'model.txt'
@@ -38,12 +38,12 @@ c     *GMOLD,GMNEW,SIGSQ,OLDB
 C*****series.txt
       CHARACTER*40 NAME
       INTEGER LEN
-      DOUBLE PRECISION TIM(500),SER(500),TDIF(500)
+      DOUBLE PRECISION TIM(5000),SER(5000),TDIF(5000)
 c      COMMON/SERIES/NAME,LEN,TIM,SER,TDIF
       COMMON/SERIES/TIM,SER,TDIF,NAME,LEN
 C*****veccom.txt
       DOUBLE PRECISION B(22),NEWB(22),PERB(22),DELB(22),
-     * ERR(500),RES(500),PRES(22,500),sres(500)
+     * ERR(5000),RES(5000),PRES(22,5000),sres(5000)
       COMMON/VECCOM/B,NEWB,PERB,DELB,ERR,RES,PRES,sres
 C*****redcom.txt
       DOUBLE PRECISION GRAD(22),SSP(22,22)
@@ -78,7 +78,6 @@ C*****model1.txt
       INTEGER LEN1, PFI1,ARP1,VRI1,CCV1
       DOUBLE PRECISION SCALE1,VR1
 
-
       PFI1=PFI
       ARP1=ARP
       NP1=NP
